@@ -1,8 +1,10 @@
-from task_commit.task_commit import git_commit
+from .core import git_commit
 
 def main():
     """
     Função principal que chama a função git_commit, para realizar o commit.
     """
+    
     git_commit()
+    
     
\ No newline at end of file
